Modules

Structs

A wrapper for EntityCommands to execute commands on entities with a specific EntityKind.
A WorldQuery used to query entities with some given EntityKind.
A Bundle inserted into all entities of given EntityKind.
A WorldQuery filter for entities with some given EntityKind.

Traits

Some kind of an Entity with an expected set of components.
Extension trait used to insert a new EntityKind into any Entity using some EntityCommands.
Extension trait which provides EntityKind support for Commands.
Extension trait used to safely cast an Entity into an EntityKind.

Derive Macros