Struct bevy_kindly::EntityKindCommands
source · pub struct EntityKindCommands<'w, 's, 'a, T: EntityKind>(_, _);Expand description
A wrapper for EntityCommands to execute commands on entities with a specific EntityKind.
Implementations
sourceimpl<'w, 's, 'a, T: EntityKind> EntityKindCommands<'w, 's, 'a, T>
impl<'w, 's, 'a, T: EntityKind> EntityKindCommands<'w, 's, 'a, T>
sourcepub unsafe fn from_entity_unchecked(entity: EntityCommands<'w, 's, 'a>) -> Self
pub unsafe fn from_entity_unchecked(entity: EntityCommands<'w, 's, 'a>) -> Self
Creates a new EntityKindCommands with some generic EntityCommands.
Safety
This function assumes entity is associated with the correct EntityKind.
sourcepub fn get(&self) -> T
pub fn get(&self) -> T
Returns the associated EntityKind.
sourcepub fn as_entity(&mut self) -> &mut EntityCommands<'w, 's, 'a>
pub fn as_entity(&mut self) -> &mut EntityCommands<'w, 's, 'a>
Returns the underying EntityCommands.
pub fn insert(&mut self, component: impl Component) -> &mut Self
pub fn remove<S: Component>(&mut self) -> &mut Self